@@ -3,7 +3,7 @@
  * For any replication type other than inserter/updater, this will fail to run if replication is currently running.
  * For any replication type other than inserter/updater, this will pause replication for the given table until validation is complete
  */
-CREATE OR REPLACE FUNCTION validate_rowcount(p_destination text, p_src_incr_less boolean DEFAULT false, p_debug boolean DEFAULT false, OUT match boolean, OUT source_count bigint, OUT dest_count bigint, OUT min_source_value text, OUT max_source_value text) RETURNS record
+CREATE FUNCTION validate_rowcount(p_destination text, p_src_incr_less boolean DEFAULT false, p_incr_interval text DEFAULT NULL, p_debug boolean DEFAULT false, OUT match boolean, OUT source_count bigint, OUT dest_count bigint, OUT min_source_value text, OUT max_source_value text) RETURNS record
     LANGUAGE plpgsql
     AS $$
 DECLARE
@@ -44,10 +44,12 @@ SELECT dest_table
     , type
     , dblink
     , condition
+    , source_table
 INTO v_dest_table
     , v_type
     , v_dblink
     , v_condition
+    , v_source_table
 FROM refresh_config
 WHERE dest_table = p_destination; 
 IF NOT FOUND THEN
@@ -58,7 +60,11 @@ IF v_type = 'snap' OR v_type = 'dml' OR v_type = 'logdel' OR v_type = 'table' TH
     v_adv_lock := @extschema@.concurrent_lock_check(v_dest_table);
 END IF;
 
-SELECT source_table INTO v_source_table FROM refresh_config WHERE dest_table = v_dest_table;
+IF v_type = 'inserter_time' OR v_type = 'inserter_serial' THEN
+    SELECT control INTO v_control FROM refresh_config_inserter WHERE dest_table = v_dest_table;
+ELSIF v_type = 'updater_time' OR v_type = 'updater_serial' THEN
+    SELECT control INTO v_control FROM refresh_config_updater WHERE dest_table = v_dest_table;
+END IF;
 
 IF v_adv_lock = 'false' THEN
     RAISE EXCEPTION 'Validation cannot run while refresh for given table is running: %', v_dest_table;
@@ -92,8 +98,16 @@ INTO v_dest_schemaname, v_dest_tablename;
 v_remote_sql := format('SELECT count(*) as row_count FROM %I.%I', v_src_schemaname, v_src_tablename);
 v_local_sql := format('SELECT count(*) FROM %I.%I', v_dest_schemaname, v_dest_tablename);
 IF v_control IS NOT NULL THEN
+
+    IF v_condition IS NOT NULL THEN
+        v_remote_sql := v_remote_sql ||' '|| v_condition || ' AND ';
+    ELSE
+        v_remote_sql := v_remote_sql ||' WHERE ';
+    END IF;
+
     IF p_src_incr_less THEN  
         v_remote_min_sql := format('SELECT min(%I) AS min_source FROM %I.%I', v_control, v_src_schemaname, v_src_tablename);
+        PERFORM gdb(p_debug, 'v_remote_min_sql: '||v_remote_min_sql);
         IF v_condition IS NOT NULL THEN
             v_remote_min_sql := v_remote_min_sql ||' '||v_condition;
         END IF;
@@ -112,18 +126,32 @@ IF v_control IS NOT NULL THEN
         END IF;
     END IF;
 
-    IF v_condition IS NOT NULL THEN
-        v_remote_sql := v_remote_sql ||' '|| v_condition || ' AND ';
-    ELSE
-        v_remote_sql := v_remote_sql ||' WHERE ';
-    END IF;
-
     IF v_type = 'inserter_time' OR v_type = 'updater_time' THEN
         EXECUTE format('SELECT max(%I) FROM %I.%I', v_control, v_dest_schemaname, v_dest_tablename) INTO v_max_dest_time;
+        -- Reduce the max value being compared by the given interval value
+        IF p_incr_interval IS NOT NULL AND v_max_dest_time IS NOT NULL THEN
+            v_max_dest_time := v_max_dest_time - p_incr_interval::interval;
+            IF p_src_incr_less THEN
+                v_local_sql := v_local_sql || ' AND ';
+            ELSE
+                v_local_sql := v_local_sql || ' WHERE ';
+            END IF;
+            v_local_sql := format(v_local_sql || ' %I <= %L', v_control, v_max_dest_time);
+        END IF;
         v_remote_sql := format(v_remote_sql ||' %I <= %L', v_control, COALESCE(v_max_dest_time, 'infinity'));
         max_source_value := v_max_dest_time::text;
     ELSIF v_type = 'inserter_serial' OR v_type = 'updater_serial' THEN
         EXECUTE format('SELECT max(%I) FROM %I.%I', v_control, v_dest_schemaname, v_dest_tablename) INTO v_max_dest_serial;
+        -- Reduce the max value being compared by the given interval value
+        IF p_incr_interval IS NOT NULL AND v_max_dest_serial IS NOT NULL THEN
+            v_max_dest_serial := v_max_dest_serial - p_incr_interval::bigint;
+            IF p_src_incr_less THEN
+                v_local_sql := v_local_sql || ' AND ';
+            ELSE
+                v_local_sql := v_local_sql || ' WHERE ';
+            END IF;
+            v_local_sql := format(v_local_sql || ' %I <= %L', v_control, v_max_dest_serial);
+        END IF;
         v_remote_sql := format(v_remote_sql ' %I <= %L', v_control, COALESCE(v_max_dest_serial, 0));
         max_source_value := v_max_dest_serial::text;
     END IF;
